'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tokens = require('../../../../design-tokens/tokens.js');
var convertValue = require('../../utils/convert-value.js');

/**
 * Pixel size values for each font that we use in the design system.
 *
 * We assert that the values match the guardian type scale in our
 * {@link [unit test suite](./typography.test.ts)}.
 *
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const pxTextSizes = {
    textSans: {
        xxsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.xxSmall.fontSize),
        xsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.xSmall.fontSize),
        small: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.small.fontSize),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.medium.fontSize),
        large: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.large.fontSize),
        xlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.xLarge.fontSize),
        xxlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.xxLarge.fontSize),
        xxxlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textSans.xxxLarge.fontSize),
    },
    body: {
        xsmall: convertValue.pxStringToNumber(tokens.tokens.typography.body.xSmall.fontSize),
        small: convertValue.pxStringToNumber(tokens.tokens.typography.body.small.fontSize),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.body.medium.fontSize),
    },
    headline: {
        xxxsmall: convertValue.pxStringToNumber(tokens.tokens.typography.headline.xxxSmall.fontSize),
        xxsmall: convertValue.pxStringToNumber(tokens.tokens.typography.headline.xxSmall.fontSize),
        xsmall: convertValue.pxStringToNumber(tokens.tokens.typography.headline.xSmall.fontSize),
        small: convertValue.pxStringToNumber(tokens.tokens.typography.headline.small.fontSize),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.headline.medium.fontSize),
        large: convertValue.pxStringToNumber(tokens.tokens.typography.headline.large.fontSize),
        xlarge: convertValue.pxStringToNumber(tokens.tokens.typography.headline.xLarge.fontSize),
    },
    titlepiece: {
        small: convertValue.pxStringToNumber(tokens.tokens.typography.titlepiece.small.fontSize),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.titlepiece.medium.fontSize),
        large: convertValue.pxStringToNumber(tokens.tokens.typography.titlepiece.large.fontSize),
    },
};
/**
 * Relative font sizes, calculated from the pixel sizes above;
 * using the pxToRem method.
 *
 * We assert that the computed rem values match the expected values
 * in our {@link [unit test suite](./typography.test.ts)}.
 *
 * See {@link [pxToRem](../utils/convert-value.ts)} for more details.
 *
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const remTextSizes = {
    textSans: {
        xxsmall: convertValue.pxToRem(pxTextSizes.textSans.xxsmall),
        xsmall: convertValue.pxToRem(pxTextSizes.textSans.xsmall),
        small: convertValue.pxToRem(pxTextSizes.textSans.small),
        medium: convertValue.pxToRem(pxTextSizes.textSans.medium),
        large: convertValue.pxToRem(pxTextSizes.textSans.large),
        xlarge: convertValue.pxToRem(pxTextSizes.textSans.xlarge),
        xxlarge: convertValue.pxToRem(pxTextSizes.textSans.xxlarge),
        xxxlarge: convertValue.pxToRem(pxTextSizes.textSans.xxxlarge),
    },
    body: {
        xsmall: convertValue.pxToRem(pxTextSizes.body.xsmall),
        small: convertValue.pxToRem(pxTextSizes.body.small),
        medium: convertValue.pxToRem(pxTextSizes.body.medium),
    },
    headline: {
        xxxsmall: convertValue.pxToRem(pxTextSizes.headline.xxxsmall),
        xxsmall: convertValue.pxToRem(pxTextSizes.headline.xxsmall),
        xsmall: convertValue.pxToRem(pxTextSizes.headline.xsmall),
        small: convertValue.pxToRem(pxTextSizes.headline.small),
        medium: convertValue.pxToRem(pxTextSizes.headline.medium),
        large: convertValue.pxToRem(pxTextSizes.headline.large),
        xlarge: convertValue.pxToRem(pxTextSizes.headline.xlarge),
    },
    titlepiece: {
        small: convertValue.pxToRem(pxTextSizes.titlepiece.small),
        medium: convertValue.pxToRem(pxTextSizes.titlepiece.medium),
        large: convertValue.pxToRem(pxTextSizes.titlepiece.large),
    },
};
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const fonts = {
    titlepiece: convertValue.fontArrayToString(tokens.tokens.typography.fontFamily.titlepiece),
    headline: convertValue.fontArrayToString(tokens.tokens.typography.fontFamily.headline),
    body: convertValue.fontArrayToString(tokens.tokens.typography.fontFamily.body),
    textSans: convertValue.fontArrayToString(tokens.tokens.typography.fontFamily.textSans),
};
/**
 * @see https://theguardian.design/2a1e5182b/p/0578f1-typography-presets/b/4704a2
 * @see https://www.figma.com/file/OqhZwB5nboFn33iHLYoc6d/%E2%97%90-Typography?type=design&node-id=384%3A3&t=mYsLeX87mBF2Uw8J-1
 *
 * Relative units ensure users can change their user-agent’s font size
 * and having the line height grow accordingly.
 *
 * We meet the Web Consortium Accessibility Guidelines’
 * success criterion for “Text Spacing” (1.4.12) as these values
 * can be overridden by users.
 *
 * @see https://www.w3.org/WAI/WCAG21/Understanding/text-spacing
 *
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const lineHeights = {
    tight: tokens.tokens.typography.lineHeight.tight,
    regular: tokens.tokens.typography.lineHeight.regular,
    loose: tokens.tokens.typography.lineHeight.loose,
};
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const fontWeights = {
    light: tokens.tokens.typography.fontWeight.light,
    regular: tokens.tokens.typography.fontWeight.regular,
    medium: tokens.tokens.typography.fontWeight.medium,
    bold: tokens.tokens.typography.fontWeight.bold,
};
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const availableFontWeights = {
    titlepiece: { bold: true },
    headline: { light: true, medium: true, bold: true },
    body: { regular: true, bold: true },
    textSans: { regular: true, bold: true },
};
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const italicsFontWeights = {
    titlepiece: { bold: false },
    headline: { light: true, medium: true, bold: false },
    body: { regular: true, bold: true },
    textSans: { regular: true, bold: false },
};
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const underlineThickness = {
    textSans: {
        xxsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[12]),
        xsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[14]),
        small: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[15]),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[17]),
        large: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[20]),
        xlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[24]),
        xxlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[28]),
        xxxlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[34]),
    },
    body: {
        xsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[14]),
        small: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[15]),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[17]),
    },
    headline: {
        xxxsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[17]),
        xxsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[20]),
        xsmall: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[24]),
        small: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[28]),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[34]),
        large: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[42]),
        xlarge: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[50]),
    },
    titlepiece: {
        small: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[42]),
        medium: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[50]),
        large: convertValue.pxStringToNumber(tokens.tokens.typography.textDecorationThicknessForFontSize[70]),
    },
};
// Pixel font size exports
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const textSansSizes = pxTextSizes.textSans;
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const bodySizes = pxTextSizes.body;
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const headlineSizes = pxTextSizes.headline;
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const titlepieceSizes = pxTextSizes.titlepiece;
// Computed rem font size exports
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const remBodySizes = remTextSizes.body;
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const remTitlepieceSizes = remTextSizes.titlepiece;
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const remHeadlineSizes = remTextSizes.headline;
/**
 * @deprecated Use typography presets rather than setting individual values
 * https://guardian.github.io/storybooks/?path=/docs/source-foundations_typography--docs
 */
const remTextSansSizes = remTextSizes.textSans;

exports.availableFontWeights = availableFontWeights;
exports.bodySizes = bodySizes;
exports.fontWeights = fontWeights;
exports.fonts = fonts;
exports.headlineSizes = headlineSizes;
exports.italicsFontWeights = italicsFontWeights;
exports.lineHeights = lineHeights;
exports.pxTextSizes = pxTextSizes;
exports.remBodySizes = remBodySizes;
exports.remHeadlineSizes = remHeadlineSizes;
exports.remTextSansSizes = remTextSansSizes;
exports.remTextSizes = remTextSizes;
exports.remTitlepieceSizes = remTitlepieceSizes;
exports.textSansSizes = textSansSizes;
exports.titlepieceSizes = titlepieceSizes;
exports.underlineThickness = underlineThickness;
//# sourceMappingURL=data.js.map
