'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var data = require('./data.js');

const determineFontStyleProperty = (fontStyle, hasItalic) => {
    switch (fontStyle) {
        case 'italic':
            return hasItalic ? 'italic' : undefined;
        case 'normal':
            return 'normal';
        case null:
        default:
            return undefined;
    }
};
/**
 * Generates a method that returns a TypographyStyles object for a given font scale.
 *
 * **Example**, generate a method that returns styles for the `headline` category
 * at the `small` level and a default font weight of `medium`:
 *
 * ```
 * const headlineSmall =
 * fontStyleFunction('headline', 'small', { fontWeight: 'medium' });
 * ```
 *
 * **Example usage**, we call the method to get our typography styles and override
 * the default font weight set above with `bold`:
 *
 * ```
 * const headlineSmallStyles =
 * headlineSmall({ fontWeight: 'bold' });
 * ```
 */
const fontStyleFunction = (category, level, defaults) => (options) => {
    var _a, _b, _c, _d;
    const finalFontConfiguration = {
        ...defaults,
        ...options,
    };
    // Fetch the font size in pixels and rems for the given category and level
    const pxTextSize = Number(data.pxTextSizes[category][level]);
    const remTextSize = Number(data.remTextSizes[category][level]);
    // Determine if italic font-style is available for this font weight
    const hasItalic = (_b = (_a = data.italicsFontWeights[category]) === null || _a === void 0 ? void 0 : _a[finalFontConfiguration.fontWeight]) !== null && _b !== void 0 ? _b : false;
    // Determine if setting the font weight is allowed for the given category
    const isFontWeightAvailable = (_d = (_c = data.availableFontWeights[category]) === null || _c === void 0 ? void 0 : _c[finalFontConfiguration.fontWeight]) !== null && _d !== void 0 ? _d : false;
    const fontWeight = isFontWeightAvailable
        ? data.fontWeights[finalFontConfiguration.fontWeight]
        : undefined;
    // line-height is defined as a unitless value, so we multiply
    // by the element's font-size in px to get the px value
    const lineHeight = finalFontConfiguration.unit === 'px'
        ? `${data.lineHeights[finalFontConfiguration.lineHeight] * pxTextSize}px`
        : data.lineHeights[finalFontConfiguration.lineHeight];
    return {
        lineHeight,
        fontWeight,
        fontSize: finalFontConfiguration.unit === 'px' ? pxTextSize : `${remTextSize}rem`,
        fontFamily: data.fonts[category],
        textDecorationThickness: Number(data.underlineThickness[category][level]),
        fontStyle: determineFontStyleProperty(finalFontConfiguration.fontStyle, hasItalic),
    };
};
/**
 * Generates a method that evaluates a given font scale function with the
 * provided options and returns the typography styles as a CSS string.
 *
 * For an example usage see our {@link [typography string function exports](./index.ts)}.
 *
 * The CSS string exposes a scoped variable: `--source-text-decoration-thickness`,
 * so consumers can use the recommended value for the font/weight combination.
 *
 * For the text underline thickness mappings see {@link underlineThickness}.
 */
const fontStyleToStringFunction = (typographyFunction) => (options) => {
    const { fontFamily, fontSize, fontStyle, fontWeight, lineHeight, textDecorationThickness, } = typographyFunction(options);
    return `
			font-family: ${fontFamily};
			font-size: ${typeof fontSize === 'number' ? `${fontSize}px` : fontSize};
			line-height: ${lineHeight};
			${fontWeight ? `font-weight: ${fontWeight};` : ''}
			${fontStyle ? `font-style: ${fontStyle};` : ''}
			--source-text-decoration-thickness: ${textDecorationThickness === undefined
        ? 'auto'
        : `${textDecorationThickness}px`};
		`;
};

exports.fontStyleFunction = fontStyleFunction;
exports.fontStyleToStringFunction = fontStyleToStringFunction;
//# sourceMappingURL=font-styles.js.map
